@@ -34,15 +34,21 @@ class Siasearch:
         self._session.set_jwt_token(self._login(self.email, password))
 
     def __str__(self):
+        if self._session is None:
+            return f"Connection to {self.server} was not established"
         return f"{self.__class__.__name__} object with user `{self.email}` connected to `{self.server}`"
 
     def __repr__(self):
         return self.__str__()
 
     def _login(self, email, password):
-        data = {"email": email, "password": password}
-        json_res = self._session.post_json(API_LOGIN_URL, data)
-        return json_res["access_token"]
+        try:
+            data = {"email": email, "password": password}
+            json_res = self._session.post_json(API_LOGIN_URL, data)
+            return json_res["access_token"]
+        except RuntimeError as e:
+            print(f"Login failed: {e}")
+            self._session = None
 
     def query(self, query: str) -> Results:
         """Query SiaSearch platform for segments
